# Relative QE factors for imaging computation script
# GG, 2022mar16
# This is intended for determinig the RQE factors for imaging twilight flatsfields. The coefficients are determined from the ratio od adjacent sections of CCD1-CCD2 and CCD-CCD3. The sections are defined in the 'imstat' commands below, and can be modified if necessary (e.g. bright stars. etc).
# Can be used for science images if needed, provided the sky background can be reliably measured.
#
# Usage:
# 1) Build the "qe_list.txt" file with the names of the bias_subtracted raw GMOS images, one per line. All must be in the *same filter* and from the *same date*
# 2) The output will be the factors for the file gmosQEfactors_mod_tw.dat, which is the one called by the task gqecorr
# 3) For correcting the flats, run: gqecorr @qe_list.txt outpref='q' qecorr_data='./gmosQEfactors_mod_tw.dat' logfile='qecorr_tw.log' 


###### RQE coeff measuring section####

print ""
print "---------------  Measuring the QE factors from images  ---------------"
 
string *list10
string *list11
string filter
delete factors*.txt
delete gmosQEfactors_local*.dat,gmosQEfactors_mod*.dat
delete tmp*


list10 = 'qe_list.txt'

real ext4
real ext5
real ext8
real ext9

print("#####", >>& "factors_list.txt")
type ("qe_list.txt",>>& "factors_list.txt")
 


while (fscan (list10, s2) != EOF) {
	
	hedit (s2//"[0]",fields="GQECORR",delete+,verify-)
	for (i=1;i<=12;i+=1){	
		hedit (s2//"["//i//"]",fields="QEFACTOR",delete+,verify-)
	}

	print(s2)

	imstat(s2//"[4][100:150,1050:1100]", fields="mean", format-) | scan(ext4) | print(ext4)
	imstat(s2//"[6][20:55,1050:1100]", fields="mean", format-) | scan(ext5) | print(ext5)
	imstat(s2//"[8][180:230,850:870]", fields="mean", format-) | scan(ext8) | print(ext8)
	imstat(s2//"[9][40:95,850:870]", fields="mean", format-) | scan(ext9) | print(ext9)

	print(ext4/ext5, ext9/ext8, ext5)
	print(ext4/ext5, ext9/ext8, ext5,>>& "factors_list.txt")

	print(ext4/ext5, >>& "factors1.txt")
	print(ext9/ext8, >>& "factors3.txt")
	
print (" ")
	
}



###### RQE coeff update section####

print ("RQE coeff update")
print " "

! awk 'NR==1 {print ($1)"[0]"}' qe_list.txt >> tmp
#hselect ("@tmp","FILTER2", "yes", >>& "tmp_filter.txt") | scan(s1)
hselect ("@tmp","FILTER2", "yes") | scan(s1)
print (s1)


copy gemini$gmos/data/gmosQEfactors.dat ./gmosQEfactors_local.dat 
#! awk '/u_G0332/ && /Hamamatsu_new/ {print}' gmosQEfactors_local.dat >> gmosQEfactors_local_single.dat  
#! awk '/g_G0325/ && /Hamamatsu_new/ {print}' gmosQEfactors_local.dat >> gmosQEfactors_local_single.dat  
#! awk '/r_G0326/ && /Hamamatsu_new/ {print}' gmosQEfactors_local.dat >> gmosQEfactors_local_single.dat  
#! awk '/i_G0327/ && /Hamamatsu_new/ {print}' gmosQEfactors_local.dat >> gmosQEfactors_local_single.dat  
#! awk '/z_G0328/ && /Hamamatsu_new/ {print}' gmosQEfactors_local.dat >> gmosQEfactors_local_single.dat  

# For GMOS-S:
match ('Hamamatsu_new', "gmosQEfactors_local.dat") | match (s1,  >& "gmosQEfactors_local_single.dat") 


# columns 1-4
! awk -v b=1 -v e=4 'BEGIN{FS=OFS=" "} {for (i=b;i<=e;i++) printf "%s%s", $i, (i<e ? OFS : ORS)}' gmosQEfactors_local_single.dat > tmp_part1


! awk 'BEGIN{s=0;}{s=s+$1;}END{print s/NR;}'  factors1.txt >> factors.txt
  print ("1.0",>>& "factors.txt")
! awk 'BEGIN{s=0;}{s=s+$1;}END{print s/NR;}'  factors3.txt >> factors.txt

# columns 6-22
! awk -v b=6 -v e=22 'BEGIN{FS=OFS=" "} {for (i=b;i<=e;i++) printf "%s%s", $i, (i<e ? OFS : ORS)}' gmosQEfactors_local_single.dat > tmp_part2

! paste tmp_part1 factors.txt tmp_part2 > gmosQEfactors_mod_tw.dat

print " "
print "Final RQE factors for this set:"
cat factors.txt
print "If the factors are close to 1.0 (within 0.5%) then you are fine"
delete tmp*

